@@ -29,7 +29,11 @@ import aws_cdk.core
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
-class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-dax.CfnCluster"):
+class CfnCluster(
+    aws_cdk.core.CfnResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-dax.CfnCluster",
+):
     """A CloudFormation ``AWS::DAX::Cluster``.
 
     see
@@ -37,7 +41,28 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
     cloudformationResource:
     :cloudformationResource:: AWS::DAX::Cluster
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, iam_role_arn: str, node_type: str, replication_factor: jsii.Number, availability_zones: typing.Optional[typing.List[str]]=None, cluster_name: typing.Optional[str]=None, description: typing.Optional[str]=None, notification_topic_arn: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, preferred_maintenance_window: typing.Optional[str]=None, security_group_ids: typing.Optional[typing.List[str]]=None, sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]]=None, subnet_group_name: typing.Optional[str]=None, tags: typing.Any=None) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        iam_role_arn: str,
+        node_type: str,
+        replication_factor: jsii.Number,
+        availability_zones: typing.Optional[typing.List[str]] = None,
+        cluster_name: typing.Optional[str] = None,
+        description: typing.Optional[str] = None,
+        notification_topic_arn: typing.Optional[str] = None,
+        parameter_group_name: typing.Optional[str] = None,
+        preferred_maintenance_window: typing.Optional[str] = None,
+        security_group_ids: typing.Optional[typing.List[str]] = None,
+        sse_specification: typing.Optional[
+            typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]
+        ] = None,
+        subnet_group_name: typing.Optional[str] = None,
+        tags: typing.Any = None,
+    ) -> None:
         """Create a new ``AWS::DAX::Cluster``.
 
         :param scope: - scope in which this resource is defined.
@@ -56,13 +81,34 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         :param subnet_group_name: ``AWS::DAX::Cluster.SubnetGroupName``.
         :param tags: ``AWS::DAX::Cluster.Tags``.
         """
-        props = CfnClusterProps(iam_role_arn=iam_role_arn, node_type=node_type, replication_factor=replication_factor, availability_zones=availability_zones, cluster_name=cluster_name, description=description, notification_topic_arn=notification_topic_arn, parameter_group_name=parameter_group_name, preferred_maintenance_window=preferred_maintenance_window, security_group_ids=security_group_ids, sse_specification=sse_specification, subnet_group_name=subnet_group_name, tags=tags)
+        props = CfnClusterProps(
+            iam_role_arn=iam_role_arn,
+            node_type=node_type,
+            replication_factor=replication_factor,
+            availability_zones=availability_zones,
+            cluster_name=cluster_name,
+            description=description,
+            notification_topic_arn=notification_topic_arn,
+            parameter_group_name=parameter_group_name,
+            preferred_maintenance_window=preferred_maintenance_window,
+            security_group_ids=security_group_ids,
+            sse_specification=sse_specification,
+            subnet_group_name=subnet_group_name,
+            tags=tags,
+        )
 
         jsii.create(CfnCluster, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnCluster":
+    def from_cloud_formation(
+        cls,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: aws_cdk.core.ICfnFinder,
+    ) -> "CfnCluster":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -77,7 +123,9 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         """
         options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -91,7 +139,9 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -278,7 +328,11 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
 
     @builtins.property
     @jsii.member(jsii_name="sseSpecification")
-    def sse_specification(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]]:
+    def sse_specification(
+        self,
+    ) -> typing.Optional[
+        typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]
+    ]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
         see
@@ -287,7 +341,12 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "sseSpecification")
 
     @sse_specification.setter
-    def sse_specification(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]]) -> None:
+    def sse_specification(
+        self,
+        value: typing.Optional[
+            typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]
+        ],
+    ) -> None:
         jsii.set(self, "sseSpecification", value)
 
     @builtins.property
@@ -304,27 +363,39 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
     def subnet_group_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "subnetGroupName", value)
 
-    @jsii.data_type(jsii_type="@aws-cdk/aws-dax.CfnCluster.SSESpecificationProperty", jsii_struct_bases=[], name_mapping={'sse_enabled': 'sseEnabled'})
-    class SSESpecificationProperty():
-        def __init__(self, *, sse_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None) -> None:
+    @jsii.data_type(
+        jsii_type="@aws-cdk/aws-dax.CfnCluster.SSESpecificationProperty",
+        jsii_struct_bases=[],
+        name_mapping={"sse_enabled": "sseEnabled"},
+    )
+    class SSESpecificationProperty:
+        def __init__(
+            self,
+            *,
+            sse_enabled: typing.Optional[
+                typing.Union[bool, aws_cdk.core.IResolvable]
+            ] = None,
+        ) -> None:
             """
             :param sse_enabled: ``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dax-cluster-ssespecification.html
             """
-            self._values = {
-            }
-            if sse_enabled is not None: self._values["sse_enabled"] = sse_enabled
+            self._values = {}
+            if sse_enabled is not None:
+                self._values["sse_enabled"] = sse_enabled
 
         @builtins.property
-        def sse_enabled(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+        def sse_enabled(
+            self,
+        ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dax-cluster-ssespecification.html#cfn-dax-cluster-ssespecification-sseenabled
             """
-            return self._values.get('sse_enabled')
+            return self._values.get("sse_enabled")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -333,13 +404,52 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'SSESpecificationProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "SSESpecificationProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="@aws-cdk/aws-dax.CfnClusterProps", jsii_struct_bases=[], name_mapping={'iam_role_arn': 'iamRoleArn', 'node_type': 'nodeType', 'replication_factor': 'replicationFactor', 'availability_zones': 'availabilityZones', 'cluster_name': 'clusterName', 'description': 'description', 'notification_topic_arn': 'notificationTopicArn', 'parameter_group_name': 'parameterGroupName', 'preferred_maintenance_window': 'preferredMaintenanceWindow', 'security_group_ids': 'securityGroupIds', 'sse_specification': 'sseSpecification', 'subnet_group_name': 'subnetGroupName', 'tags': 'tags'})
-class CfnClusterProps():
-    def __init__(self, *, iam_role_arn: str, node_type: str, replication_factor: jsii.Number, availability_zones: typing.Optional[typing.List[str]]=None, cluster_name: typing.Optional[str]=None, description: typing.Optional[str]=None, notification_topic_arn: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, preferred_maintenance_window: typing.Optional[str]=None, security_group_ids: typing.Optional[typing.List[str]]=None, sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]]=None, subnet_group_name: typing.Optional[str]=None, tags: typing.Any=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-dax.CfnClusterProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "iam_role_arn": "iamRoleArn",
+        "node_type": "nodeType",
+        "replication_factor": "replicationFactor",
+        "availability_zones": "availabilityZones",
+        "cluster_name": "clusterName",
+        "description": "description",
+        "notification_topic_arn": "notificationTopicArn",
+        "parameter_group_name": "parameterGroupName",
+        "preferred_maintenance_window": "preferredMaintenanceWindow",
+        "security_group_ids": "securityGroupIds",
+        "sse_specification": "sseSpecification",
+        "subnet_group_name": "subnetGroupName",
+        "tags": "tags",
+    },
+)
+class CfnClusterProps:
+    def __init__(
+        self,
+        *,
+        iam_role_arn: str,
+        node_type: str,
+        replication_factor: jsii.Number,
+        availability_zones: typing.Optional[typing.List[str]] = None,
+        cluster_name: typing.Optional[str] = None,
+        description: typing.Optional[str] = None,
+        notification_topic_arn: typing.Optional[str] = None,
+        parameter_group_name: typing.Optional[str] = None,
+        preferred_maintenance_window: typing.Optional[str] = None,
+        security_group_ids: typing.Optional[typing.List[str]] = None,
+        sse_specification: typing.Optional[
+            typing.Union[
+                aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"
+            ]
+        ] = None,
+        subnet_group_name: typing.Optional[str] = None,
+        tags: typing.Any = None,
+    ) -> None:
         """Properties for defining a ``AWS::DAX::Cluster``.
 
         :param iam_role_arn: ``AWS::DAX::Cluster.IAMRoleARN``.
@@ -360,20 +470,30 @@ class CfnClusterProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html
         """
         self._values = {
-            'iam_role_arn': iam_role_arn,
-            'node_type': node_type,
-            'replication_factor': replication_factor,
+            "iam_role_arn": iam_role_arn,
+            "node_type": node_type,
+            "replication_factor": replication_factor,
         }
-        if availability_zones is not None: self._values["availability_zones"] = availability_zones
-        if cluster_name is not None: self._values["cluster_name"] = cluster_name
-        if description is not None: self._values["description"] = description
-        if notification_topic_arn is not None: self._values["notification_topic_arn"] = notification_topic_arn
-        if parameter_group_name is not None: self._values["parameter_group_name"] = parameter_group_name
-        if preferred_maintenance_window is not None: self._values["preferred_maintenance_window"] = preferred_maintenance_window
-        if security_group_ids is not None: self._values["security_group_ids"] = security_group_ids
-        if sse_specification is not None: self._values["sse_specification"] = sse_specification
-        if subnet_group_name is not None: self._values["subnet_group_name"] = subnet_group_name
-        if tags is not None: self._values["tags"] = tags
+        if availability_zones is not None:
+            self._values["availability_zones"] = availability_zones
+        if cluster_name is not None:
+            self._values["cluster_name"] = cluster_name
+        if description is not None:
+            self._values["description"] = description
+        if notification_topic_arn is not None:
+            self._values["notification_topic_arn"] = notification_topic_arn
+        if parameter_group_name is not None:
+            self._values["parameter_group_name"] = parameter_group_name
+        if preferred_maintenance_window is not None:
+            self._values["preferred_maintenance_window"] = preferred_maintenance_window
+        if security_group_ids is not None:
+            self._values["security_group_ids"] = security_group_ids
+        if sse_specification is not None:
+            self._values["sse_specification"] = sse_specification
+        if subnet_group_name is not None:
+            self._values["subnet_group_name"] = subnet_group_name
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def iam_role_arn(self) -> str:
@@ -382,7 +502,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-iamrolearn
         """
-        return self._values.get('iam_role_arn')
+        return self._values.get("iam_role_arn")
 
     @builtins.property
     def node_type(self) -> str:
@@ -391,7 +511,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-nodetype
         """
-        return self._values.get('node_type')
+        return self._values.get("node_type")
 
     @builtins.property
     def replication_factor(self) -> jsii.Number:
@@ -400,7 +520,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-replicationfactor
         """
-        return self._values.get('replication_factor')
+        return self._values.get("replication_factor")
 
     @builtins.property
     def availability_zones(self) -> typing.Optional[typing.List[str]]:
@@ -409,7 +529,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-availabilityzones
         """
-        return self._values.get('availability_zones')
+        return self._values.get("availability_zones")
 
     @builtins.property
     def cluster_name(self) -> typing.Optional[str]:
@@ -418,7 +538,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-clustername
         """
-        return self._values.get('cluster_name')
+        return self._values.get("cluster_name")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -427,7 +547,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def notification_topic_arn(self) -> typing.Optional[str]:
@@ -436,7 +556,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-notificationtopicarn
         """
-        return self._values.get('notification_topic_arn')
+        return self._values.get("notification_topic_arn")
 
     @builtins.property
     def parameter_group_name(self) -> typing.Optional[str]:
@@ -445,7 +565,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-parametergroupname
         """
-        return self._values.get('parameter_group_name')
+        return self._values.get("parameter_group_name")
 
     @builtins.property
     def preferred_maintenance_window(self) -> typing.Optional[str]:
@@ -454,7 +574,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-preferredmaintenancewindow
         """
-        return self._values.get('preferred_maintenance_window')
+        return self._values.get("preferred_maintenance_window")
 
     @builtins.property
     def security_group_ids(self) -> typing.Optional[typing.List[str]]:
@@ -463,16 +583,20 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-securitygroupids
         """
-        return self._values.get('security_group_ids')
+        return self._values.get("security_group_ids")
 
     @builtins.property
-    def sse_specification(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]]:
+    def sse_specification(
+        self,
+    ) -> typing.Optional[
+        typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]
+    ]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-ssespecification
         """
-        return self._values.get('sse_specification')
+        return self._values.get("sse_specification")
 
     @builtins.property
     def subnet_group_name(self) -> typing.Optional[str]:
@@ -481,7 +605,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-subnetgroupname
         """
-        return self._values.get('subnet_group_name')
+        return self._values.get("subnet_group_name")
 
     @builtins.property
     def tags(self) -> typing.Any:
@@ -490,7 +614,7 @@ class CfnClusterProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -499,11 +623,17 @@ class CfnClusterProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnClusterProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnClusterProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
-class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-dax.CfnParameterGroup"):
+class CfnParameterGroup(
+    aws_cdk.core.CfnResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-dax.CfnParameterGroup",
+):
     """A CloudFormation ``AWS::DAX::ParameterGroup``.
 
     see
@@ -511,7 +641,16 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
     cloudformationResource:
     :cloudformationResource:: AWS::DAX::ParameterGroup
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, description: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, parameter_name_values: typing.Any=None) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        description: typing.Optional[str] = None,
+        parameter_group_name: typing.Optional[str] = None,
+        parameter_name_values: typing.Any = None,
+    ) -> None:
         """Create a new ``AWS::DAX::ParameterGroup``.
 
         :param scope: - scope in which this resource is defined.
@@ -520,13 +659,24 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
         :param parameter_group_name: ``AWS::DAX::ParameterGroup.ParameterGroupName``.
         :param parameter_name_values: ``AWS::DAX::ParameterGroup.ParameterNameValues``.
         """
-        props = CfnParameterGroupProps(description=description, parameter_group_name=parameter_group_name, parameter_name_values=parameter_name_values)
+        props = CfnParameterGroupProps(
+            description=description,
+            parameter_group_name=parameter_group_name,
+            parameter_name_values=parameter_name_values,
+        )
 
         jsii.create(CfnParameterGroup, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnParameterGroup":
+    def from_cloud_formation(
+        cls,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: aws_cdk.core.ICfnFinder,
+    ) -> "CfnParameterGroup":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -541,7 +691,9 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
         """
         options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -555,7 +707,9 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -615,9 +769,23 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
         jsii.set(self, "parameterGroupName", value)
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-dax.CfnParameterGroupProps", jsii_struct_bases=[], name_mapping={'description': 'description', 'parameter_group_name': 'parameterGroupName', 'parameter_name_values': 'parameterNameValues'})
-class CfnParameterGroupProps():
-    def __init__(self, *, description: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, parameter_name_values: typing.Any=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-dax.CfnParameterGroupProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "description": "description",
+        "parameter_group_name": "parameterGroupName",
+        "parameter_name_values": "parameterNameValues",
+    },
+)
+class CfnParameterGroupProps:
+    def __init__(
+        self,
+        *,
+        description: typing.Optional[str] = None,
+        parameter_group_name: typing.Optional[str] = None,
+        parameter_name_values: typing.Any = None,
+    ) -> None:
         """Properties for defining a ``AWS::DAX::ParameterGroup``.
 
         :param description: ``AWS::DAX::ParameterGroup.Description``.
@@ -627,11 +795,13 @@ class CfnParameterGroupProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html
         """
-        self._values = {
-        }
-        if description is not None: self._values["description"] = description
-        if parameter_group_name is not None: self._values["parameter_group_name"] = parameter_group_name
-        if parameter_name_values is not None: self._values["parameter_name_values"] = parameter_name_values
+        self._values = {}
+        if description is not None:
+            self._values["description"] = description
+        if parameter_group_name is not None:
+            self._values["parameter_group_name"] = parameter_group_name
+        if parameter_name_values is not None:
+            self._values["parameter_name_values"] = parameter_name_values
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -640,7 +810,7 @@ class CfnParameterGroupProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def parameter_group_name(self) -> typing.Optional[str]:
@@ -649,7 +819,7 @@ class CfnParameterGroupProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parametergroupname
         """
-        return self._values.get('parameter_group_name')
+        return self._values.get("parameter_group_name")
 
     @builtins.property
     def parameter_name_values(self) -> typing.Any:
@@ -658,7 +828,7 @@ class CfnParameterGroupProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parameternamevalues
         """
-        return self._values.get('parameter_name_values')
+        return self._values.get("parameter_name_values")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -667,11 +837,17 @@ class CfnParameterGroupProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnParameterGroupProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnParameterGroupProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
-class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-dax.CfnSubnetGroup"):
+class CfnSubnetGroup(
+    aws_cdk.core.CfnResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-dax.CfnSubnetGroup",
+):
     """A CloudFormation ``AWS::DAX::SubnetGroup``.
 
     see
@@ -679,7 +855,16 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
     cloudformationResource:
     :cloudformationResource:: AWS::DAX::SubnetGroup
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, subnet_ids: typing.List[str], description: typing.Optional[str]=None, subnet_group_name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        subnet_ids: typing.List[str],
+        description: typing.Optional[str] = None,
+        subnet_group_name: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::DAX::SubnetGroup``.
 
         :param scope: - scope in which this resource is defined.
@@ -688,13 +873,24 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         :param description: ``AWS::DAX::SubnetGroup.Description``.
         :param subnet_group_name: ``AWS::DAX::SubnetGroup.SubnetGroupName``.
         """
-        props = CfnSubnetGroupProps(subnet_ids=subnet_ids, description=description, subnet_group_name=subnet_group_name)
+        props = CfnSubnetGroupProps(
+            subnet_ids=subnet_ids,
+            description=description,
+            subnet_group_name=subnet_group_name,
+        )
 
         jsii.create(CfnSubnetGroup, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnSubnetGroup":
+    def from_cloud_formation(
+        cls,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: aws_cdk.core.ICfnFinder,
+    ) -> "CfnSubnetGroup":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -709,7 +905,9 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         """
         options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -723,7 +921,9 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -783,9 +983,23 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         jsii.set(self, "subnetGroupName", value)
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-dax.CfnSubnetGroupProps", jsii_struct_bases=[], name_mapping={'subnet_ids': 'subnetIds', 'description': 'description', 'subnet_group_name': 'subnetGroupName'})
-class CfnSubnetGroupProps():
-    def __init__(self, *, subnet_ids: typing.List[str], description: typing.Optional[str]=None, subnet_group_name: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-dax.CfnSubnetGroupProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "subnet_ids": "subnetIds",
+        "description": "description",
+        "subnet_group_name": "subnetGroupName",
+    },
+)
+class CfnSubnetGroupProps:
+    def __init__(
+        self,
+        *,
+        subnet_ids: typing.List[str],
+        description: typing.Optional[str] = None,
+        subnet_group_name: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::DAX::SubnetGroup``.
 
         :param subnet_ids: ``AWS::DAX::SubnetGroup.SubnetIds``.
@@ -796,10 +1010,12 @@ class CfnSubnetGroupProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html
         """
         self._values = {
-            'subnet_ids': subnet_ids,
+            "subnet_ids": subnet_ids,
         }
-        if description is not None: self._values["description"] = description
-        if subnet_group_name is not None: self._values["subnet_group_name"] = subnet_group_name
+        if description is not None:
+            self._values["description"] = description
+        if subnet_group_name is not None:
+            self._values["subnet_group_name"] = subnet_group_name
 
     @builtins.property
     def subnet_ids(self) -> typing.List[str]:
@@ -808,7 +1024,7 @@ class CfnSubnetGroupProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetids
         """
-        return self._values.get('subnet_ids')
+        return self._values.get("subnet_ids")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -817,7 +1033,7 @@ class CfnSubnetGroupProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def subnet_group_name(self) -> typing.Optional[str]:
@@ -826,7 +1042,7 @@ class CfnSubnetGroupProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetgroupname
         """
-        return self._values.get('subnet_group_name')
+        return self._values.get("subnet_group_name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -835,7 +1051,9 @@ class CfnSubnetGroupProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnSubnetGroupProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnSubnetGroupProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
